# APL

To use this language, use the class "language-apl".

## Comments

    #!/usr/bin/env runapl
    a←1 2 3 ⍝ this is a comment

## Strings

    ''
    'foobar'
    'foo''bar''baz'

## Numbers

    42
    3.14159
    ¯2
    ∞
    2.8e¯4
    2j3
    ¯4.3e2J1.9e¯4

## Primitive functions

    a+b×c⍴⍳10

## Operators

    +/ f⍣2

## Dfns

    {0=⍴⍴⍺:'hello' ⋄ ∇¨⍵}

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    'This string is ⍝ broken'